clear all
close all
clc

%-------------------------------------------------------------------
%------------------IRREGULAR WAVES----------------------------------
%-------------------------------------------------------------------

%   %    %  % % %  %     %  % % % %
%   % %  %  %   %  %     %     %
%   %  % %  % % %  %     %     %
%   %   %%  %      %     %     %
%   %    %  %      % % % %     %
Tp =5;                                                                     % Wave period [s]
Hs = 4;   
%-------------------------------------------------------------------
%------------AA33---------------------------------------------------
%-------------------------------------------------------------------

fid=fopen('addedmass.txt','r');                                             % Reading file
data=fscanf(fid,'%f%f\n',[2 Inf]);                                          % Collecting data from file
w=data(1,1:length(data))' ;                                                 % First column: wave frequency [rad/s]
ww=w;
wA33=w;
a3=data(2,1:length(data)) ;                                                 % Second column: added mass amplitude [kg]
A33C= interp1(w,a3,ww)';
fclose(fid);

%-------------------------------------------------------------------
%------------B33----------------------------------------------------
%-------------------------------------------------------------------
fed=fopen('damping.txt','r');                                               % Reading file
datab=fscanf(fed,'%f%f\n',[2 Inf]);                                         % Collecting data from file
b3=datab(2,1:length(datab));                                                % Second column: damping amplitude [kg/s]
wB33=datab(1,1:length(datab));
B33C= interp1(w,b3,ww)';
fclose(fed);

%-------------------------------------------------------------------
%------------RAO----------------------------------------------------
%-------------------------------------------------------------------
fad=fopen('RAO.txt','r');                                                   % Reading file
datar=fscanf(fad,'%f%f\n',[2 Inf]);                                         % Collecting data from file
c3=datar(2,1:length(datar));                                                % Second column: RAO of the heave motion [m/m]
wc3=datar(1,1:length(datar));
RAO33C= interp1(w,c3,ww)';
fclose(fad);

%-------------------------------------------------------------------
%------------Excitation Force---------------------------------------
%-------------------------------------------------------------------
fud=fopen('exforce.txt','r');                                               % Reading file
datah=fscanf(fud,'%f%f\n',[2 Inf]);                                         % Collecting data from file
H=datah(2,1:length(datah));                                                 % Second column: Excitation force for heave motion [N/m]
wH=datah(1,1:length(datah));
F33C= interp1(w,H,ww)';
fclose(fud);
%-------------------------------------------------------------------
%-------------------------------------------------------------------
%-------------------------------------------------------------------
                                                                  % Wave heigth [m]
bias=0.00000001;                                                            % Tolerance
rho =1025;                                                                  % Density sea water [kg/m^3]
g   =9.81;                                                                  % Gravity constant [m/s^2]
B=8;                                                                        % Width of the CorPower WEC
m=60000;                                                                    % Mass of the CorPower WEC [kg]
Aw=pi*(B/2)^2;

%-------------------------------------------------------------------------
%-------------------------JONSWAP-----------------------------------------
%-------------------------------------------------------------------------
fod = fopen('JonswapResults.dat', 'w');                                     %Opens the output file
fprintf(fod, '%w %Sw\n','w','Sw');
food = fopen('Responsamp.dat', 'w');                                     %Opens the output file
fprintf(food, '%w %eta3a','w','eta3a');
fp  =1./Tp;
alphajonswap = 0.036 - 0.0056*(Tp/sqrt(Hs));


if Tp/sqrt(Hs) < 3.6
    gamma = 5;
elseif Tp/sqrt(Hs) > 5
    gamma = 1;
else
    gamma = exp(5.75-1.15*Tp/sqrt(Hs));
end

sigma_a = 0.07;
sigma_b = 0.09;
f=w./(2*pi);

f=f';
w=w';

%-------------------------------------------------------------------------
%-------------------------Power vs. Time----------------------------------
%-------------------------------------------------------------------------
alpha=(Hs/(4*g))^2*(2*pi*fp)^4*(0.065*gamma^0.803...
    + 0.135)^-1;

for i = 1:length(f)
    if f(i)<= fp
        sigma = sigma_a;
    else
        sigma = sigma_b;
    end
    
    
    Sf(i)=alpha*g^2*(2*pi)^-4*f(i)^-5*exp(-5/4*(fp/f(i))^4)...
        *gamma^exp(-(f(i)/fp-1)^2/(2*sigma^2));
    Sw(i)=Sf(i)/(2*pi);
    
    %     % Energy periods [s]
    %    m_0(i)=sum(Sf(i)*f(i))*Df(i)+bias;
    %
    %             m_1(i)=sum(Sf(i)/f(i))*Df(i)+bias;
    % %             m0=sum(m_0(j+1));
    % %             m1=sum(m_1(j+1));
    %              Te=2*pi*m_1/m_0;
end
A=[w;Sw];
fprintf( fud, '%1.4f %2.4f\n',A );
jonswapdata=loaddata;
Sw_list=jonswapdata(:,2);
[Sw_max,location_list]=max(Sw_list);
w_Sw_max=jonswapdata(:,1);
wsw = w_Sw_max(location_list);

%--------------------------------------------------------------------------

%--------------Finding A33 value for omega at Sw_max-----------------------
A33data=loaddataA33;
[Sw_max,location_list]=max(Sw_list);
A33_list=A33data(:,2);
A33_Cres = A33_list(location_list);
%--------------Finding RAO value for omega at Sw_max-----------------------
RAOdata=loaddataRAO;
[Sw_max,location_list]=max(Sw_list);
RAO_list=RAOdata(:,2);
RAO_Cres = RAO_list(location_list);
%--------------Finding EX_Force value for omega at Sw_max------------------
EXdata=loaddataEx;
[Sw_max,location_list]=max(Sw_list);
EX_list=EXdata(:,2);
EX_Cres = EX_list(location_list);
%--------------Finding B33 value for omega at Sw_max-----------------------
B33data=loaddataB33;
[Sw_max,location_list]=max(Sw_list);
B33_list=B33data(:,2);
% B33_Cres = B33_list(location_list);

%--------------------------------------------------------------------------
r=2;
 C33res=(wsw^r)*(m+A33_Cres);

% cstat=rho*g*Aw;
% C33res=cstat;

% cresult=cstat-C33res;
Time = 2000;
dt= 0.5;
numT = Time/dt;

nfreq = length(w);
for x=1:numT
    timeseries(x) = -dt + dt*x;
end


for j = 1:nfreq-1
    epsilon(j)=rand()*2*pi;
end


for t=1:numT
    for j=1:nfreq-1
        if t==1
            DW(j) = w(j+1)-w(j);                                           %Sets the wave frequencies at midpoint DW values
            
            Amp1W(j+1)=sqrt(2*Sw(1,j)*DW(j));                                 %Wave elevation amp for each freq. band
            Amp2W(j+1)=sqrt(2*Sw(1,j+1)*DW(j));
            AmpW(j+1) = (Amp1W(j)+Amp2W(j))/2;
            amt=sum(AmpW);
            w(j) = w(j) + (w(j) - w(j))/2;
            Ampws(j+1)=sqrt(2*Sw(1,j)*w(j));
            %-------------------Taking mean--------------------------------
            B33(j) = b3(j) + (b3(j+1)-b3(j))/2;
            
            A33(j) = a3(j) + (a3(j+1)-a3(j))/2;
            
            F33(j) = H(j) + (H(j+1)-H(j))/2;
            
            zeta_a(j+1)=AmpW(j)*w(j);
            zeta_aa=sum(zeta_a);
            eta_3a= RAO33C*zeta_aa;
            eta_3aa=real(eta_3a);
            
            
            
            % B=[w;eta_3aa];
            % fprintf( food, '%1.9f %2.4f\n',B );
            % etadata=loaddataeta;
            % eta_list=etadata(:,2);
            % etares = eta_list(location_list);
            % r=2;
            i=-1;
            C33(j+1) = C33res;
            C332(j+1)=rho*g*Aw;
            Bpto(j+1)=real(sqrt(B33(j)^2+(w(j)*(m+A33(j))-(C33(j+1)./w(j))).^2));
            
            P(j+1) = 0.5*(Bpto(j+1)*(abs(F33(j)*AmpW(j)))^2)/((Bpto(j+1)+B33(j))^2 + (w(j)...
                *(m+A33(j))-C33(j)/w(j))^2);
            %             eta_3apto(j+1)=(F33(j)*Ampws(j))/sqrt(((C332(j)-(m+A33(j)))*w(j).^2).^2+(B33(j)*w(j)).^2);
          
            Pirr(j+1)=sum(P(j+1)*2*Ampws(j+1)^2);
            eta_3apto(j+1)=abs(real((F33(j)*AmpW(j))/(-w(j).^2*(m+A33(j))+i*w(j)*(Bpto(j+1)+B33(j))+C33(j))));
            %             eta_3apto(j+1)=(F33(j)*Ampws(j+1))/sqrt((C33(j+1)-(m+A33(j))*w(j)^2)^2+(Bpto(j+1)+B33(j))^2);
          
            Hp(j+1) = (Bpto(j+1)*(abs(F33(j)*Ampws(j+1)))^2)/((Bpto(j+1)+B33(j))^2+ (w(j)*(m+A33(j))-C33(j)/w(j))^2);
           
            RAO_pto(j+1) = (eta_3apto(j+1)/Ampws(j+1));
            
            m_0(j)=sum (Sw(j)*DW(j))+bias;
            
            m_1(j)=sum(Sw(j)/w(j)*DW(j))+bias;
            % %             m0=sum(m_0(j+1));
            % %             m1=sum(m_1(j+1));
            Te=(2*pi)*(m_1/m_0);
            
            Fp(j) = 8*Hp(j).*Sw(j);
            
            % Power per meter of an irregular wave
            
            
            
        end
        
        PP(t,j) = AmpW(j)*abs(Pirr(j))*cos(w(j)*(dt*t) + epsilon(j));
        
        %f33(t,j) = AmpW(j)*abs(H(j))*cos(w(j)*dt*t + epsilon(j));
        %f33(t,j) = abs(f33(t,j));
        %b33(t,j) = AmpW(j)*abs(b3(j))*cos(w(j)*dt*t + epsilon(j));
        %a33(t,j) = AmpW(j)*abs(a3(j))*cos(w(j)*dt*t + epsilon(j));
        %c33(t,j) = AmpW(j)*abs(c3(j))*cos(w(j)*dt*t + epsilon(j));
        %P(t,j) = 0.5*((b33(t,j)*f33(t,j)^2)/((2*b33(t,j)^2)+(w(j)*(8000+a33(t,j)) - c33(t,j)/w(j))^2));
    end
    PPP(t) = abs(sum(PP(t,:)));
    PPP(t) = (PPP(t));
end

E_irrwave = (rho*g^2/(64*pi))*Hs^2*Te*B;

fclose(fod);
fclose(food);

MeanPower = mean(PPP)
for t=1:numT
    powermean(t)=MeanPower;
end
CaptureWidth=MeanPower/E_irrwave
eff=CaptureWidth/B
%--------------------------------------------------------------------------
%------------------------Plots---------------------------------------------
%--------------------------------------------------------------------------
plot(w,zeta_a)
% figure (1)
% plot(w,a3)
% grid on
% title('Added mass in heave')
% xlabel('\omega [rad/s]')
% ylabel('A_{33} [kg]')
%
% figure (2)
% plot(w,b3)
% hold on
% % plot (w,Bpto)
% % grid on
% title('Damping in heave ')
% xlabel('\omega [rad/s]')
% ylabel('B_{33} [kg/s]')
%
% figure (3)
% plot(w,c3)
% grid on
% title('RAO in heave')
% xlabel('\omega [rad/s]')
% ylabel('$$ \frac{\eta_3}{\zeta_a} [-]$$','interpreter','latex')
% set(get(gca,'ylabel'),'Rotation',0)
% hold on
% plot(w,RAO_pto)
% %
% % figure (4)
% % plot(w,H)
% % grid on
% % title('Excitation force in heave')
% % xlabel('\omega [rad/s]')
% % ylabel('F_{3a} [N]')
% %
% figure (5)
% plot(w,Sw)
% grid on
% title(sprintf('JONSWAP spectrum with Hs=%0.1f, Tp = %d', Hs, Tp))
% xlabel('\omega [rad/s]')
% ylabel('S(\omega) m^2s')
% %
% figure (6)
% plot(timeseries,PPP)
% grid on
% hold on
% plot(timeseries,powermean)
% title(sprintf('Power vs. Time'))
% xlabel('Time [s]')
% ylabel('Power [W]')
% figure (7)
% plot(w,AmpW)
% hold on
% plot(w,Amp1W)
% hold on
% plot(w,Amp2W)
% hold on
% plot(w,Ampws)
% figure (8)
% plot(w,eta_3apto)
% hold on
% plot(w,Ampws)
% figure (8)
% plot(w,Hp)
% 
% 
% 
