clear all
close all
clc

%-------------------------------------------------------------------
%------------------REGULAR WAVES----------------------------------
%-------------------------------------------------------------------

%   %    %  % % %  %     %  % % % %
%   % %  %  %   %  %     %     %
%   %  % %  % % %  %     %     %
%   %   %%  %      %     %     %
%   %    %  %      % % % %     %

%-------------------------------------------------------------------
%------------AA33---------------------------------------------------
%-------------------------------------------------------------------

fid=fopen('addedmass.txt','r');                                             % Reading file
data=fscanf(fid,'%f%f\n',[2 Inf]);                                          % Collecting data from file
fclose(fid);
w=data(1,1:length(data))' ;                                                 % First column: wave frequency [rad/s]
a3=data(2,1:length(data)) ;                                                 % Second column: added mass amplitude [kg]

%-------------------------------------------------------------------
%------------B33----------------------------------------------------
%-------------------------------------------------------------------
fed=fopen('damping.txt','r');                                               % Reading file
datab=fscanf(fed,'%f%f\n',[2 Inf]);                                         % Collecting data from file
fclose(fed);
b3=datab(2,1:length(datab));                                                % Second column: damping amplitude [kg/s]


%-------------------------------------------------------------------
%------------RAO----------------------------------------------------
%-------------------------------------------------------------------
fad=fopen('RAO.txt','r');                                                   % Reading file
datar=fscanf(fad,'%f%f\n',[2 Inf]);                                         % Collecting data from file
fclose(fad);
c3=datar(2,1:length(datar));                                                % Second column: RAO of the heave motion [m/m]


%-------------------------------------------------------------------
%------------Excitation Force---------------------------------------
%-------------------------------------------------------------------
fad=fopen('exforce.txt','r');                                               % Reading file
datar=fscanf(fad,'%f%f\n',[2 Inf]);                                         % Collecting data from file
fclose(fad);
H=datar(2,1:length(datar));                                                 % Second column: Excitation force for heave motion [N/m]

%-------------------------------------------------------------------
%-------------------------------------------------------------------
%-------------------------------------------------------------------
Tp = [5];                                                                     % Wave period [s]
Hs = [3];                                                                     % Wave heigth [m]
bias=0.00000001;                                                            % Tolerance
rho =1025;                                                                  % Density sea water [kg/m^3]
g   =9.81;                                                                  % Gravity constant [m/s^2]
B=8;                                                                        % Width of the CorPower WEC
m=80000;                                                                    % Mass of the CorPower WEC [kg]

%-------------------------------------------------------------------------
%-------------------------Power vs. Time----------------------------------
%-------------------------------------------------------------------------


Time = 30;
dt= 0.1;
numT = Time/(dt);

nfreq = length(w);
for x=1:numT
    timeseries(x) = -dt + dt*x;
end



for t=1:numT
    for j=1:nfreq-1
        if t==1
            DW(j) = w(j+1)-w(j);                                            %Sets the wave frequencies at midpoint DW values
            AmpW(j) = Hs/2;
            
            w(j) = (2*pi)/Tp;
            %-------------------Taking mean--------------------------------------------
            
            B33(j) = b3(j) + (b3(j+1)-b3(j))/2;
            B_pto(j)=B33(j);
            A33(j) = a3(j) + (a3(j+1)-a3(j))/2;
            C33(j) = rho*g*pi*4^2;
            F33(j) = H(j) + (H(j+1)-H(j))/2;
            
            Preg(j+1) = 0.5*(B33(j)*(abs(F33(j)))^2)/((2*B33(j))^2 + (w(j)...
                *(m+A33(j))-C33(j)/w(j))^2);
            
            Hpreg(j+1) = (B33(j)*(abs(F33(j)/(Hs/2)))^2)/((2*...
                B33(j))^2+ (w(j)*(m+A33(j))-C33(j)/w(j))^2);
            
            eta_3a(j+1)= (F33(j))/(-w(j)^2*(m+A33(j))'+1j*w(j)*...            % Heave amplitude [m]
                (2*B33(j)'+C33(j)));
            
            eta_3aa(j+1)=real(eta_3a(j+1));
            
            RAO_pto(j+1) = abs(eta_3aa(j+1)/(Hs/2));
            
            
            
            
            
        end
        
        
        PP(t,j) = AmpW(j)*abs(Preg(j))*cos(w(j)*(dt*t));
        
        
        
    end
    PPP(t) = abs((PP(t,:)));
    PPPP(t) = smooth(PPP(t));
    
end

MeanPower = mean(PPP);
for t=1:numT
    powermean(t)=MeanPower;
end
E_regwave = (rho*g^2/(32*pi))*Hs^2*Tp*B;                         % Power per meter of an irregular wave

W_reg = MeanPower/E_regwave;                                       % Capture width

eff_reg = W_reg/B;                                            % Capture width efficiency

%--------------------------------------------------------------------------
%------------------------Plots---------------------------------------------
%--------------------------------------------------------------------------

% figure (1)
% plot(w,a3)
% grid on
% title('Added mass in heave')
% xlabel('\omega [rad/s]')
% ylabel('A_{33} [kg]')
%
% figure (2)
% plot(w,b3)
% grid on
% title('Damping in heave without PTO')
% xlabel('\omega [rad/s]')
% ylabel('B_{33} [kg/s]')
%
% figure (3)
% plot(w,c3)
% grid on
% title('RAO in heave without PTO')
% xlabel('\omega [rad/s]')
% ylabel('$$ \frac{\eta_3}{\zeta_a} [-]$$','interpreter','latex')
% set(get(gca,'ylabel'),'Rotation',0)
%
% figure (4)
% plot(w,H)
% grid on
% title('Excitation force in heave')
% xlabel('\omega [rad/s]')
% ylabel('F_{3a} [N]')
%
figure (6)
plot(timeseries,PPP)
grid on
hold on
plot(timeseries,powermean)
title(sprintf('Regular Waves Power vs. Time'))
xlabel('Time [s]')
ylabel('Power [W]')
