
%Master Thesis Combined Wind an Waave Power
%Developed by Rasmus Borenius
%June 2015
 clear 
 clear all 

%SCOPE: find chordlength and theta distribution (values that physically
%describes the whole wing. (chapt 8) then use BEM method to calculate
%forces and coefficients for this design (chapt 7)
% File handler
fid = fopen( 'ResultsConstTSR.dat', 'w' );      % Open the output file
fprintf( fid, 'V | Total power | Power coefficient | Total Thrust \n\n');
fid2 = fopen( 'Ashes.dat', 'w' ); 
fprintf( fid2, 'theta | Lc \n\n');
%blade elements
N=100;   
%wind turbin diameter
d=126;  
%number of blades
Z=3;   
dens=1.225;
%first blade element starts at : hub radius + circular disk = 8 meters
r0=6;
%total radius from center of hub to tip of blade
rend=63;
% radius of only the blade without circular disk and hub
R=rend-r0;
%steps between blade elements
dr=R/N;
%midpoint of elements
r=r0+dr/2:dr:rend;

r=r';
% starting at 1e-10 instead of 0 to awoid NaN
bias = 1e-10;   
% wind velocity in m/s
V_vec = 10;
% V_vec = 1:0.1:20;  
% tip speed ratio
TSR= 8;  

for i = V_vec
     V = i+bias; 
      omega=TSR*V/(d/2);
lambda_r=omega/V*r;
[a, adot, Bep, phi ]=adisk(lambda_r,N);%calculating local lamdas from table 107

phi=phi';
a=a';
adot=adot';
Bep=Bep';

airfoil_data=loaddata;

lift_to_drag_list=airfoil_data(:,2)./airfoil_data(:,3);

[lift_to_drag_max,location_list]=max(lift_to_drag_list);

AoA_opt_deg=airfoil_data(location_list,1);
AoA_opt_rad=AoA_opt_deg*2*pi/360;

C_lift_opt=airfoil_data(location_list,2);
C_drag_opt=airfoil_data(location_list,3);


Lc=Bep*2*pi*V/(Z*C_lift_opt*omega);

 sigma=Z*Lc./(2*pi*r);
 a_critical=0.2;
 eps=10^-6; %toleranse 
 error=1;
  counter=0 ;
theta=phi-AoA_opt_rad;  %locked 
  a=0.25*ones(N,1);   %must be chosen in the interval [0.25, 0.33]
  adot=0.01*zeros(N,1);
% adot=0.333*(N,1);
% a=0.001*ones(N,1);

for j=1:N    
    counter=counter+1;
    phi(j)=(atan((V*(1-a(j))/((1+adot(j))*r(j)*omega))));  
    theta(j)=phi(j)-AoA_opt_rad;
    F(j)=(2/pi)*acos(exp(-(Z/2)*((rend-r(j))/(r(j)*sin(phi(j))))));
%     AoA_deg(j)=(phi(j)-theta(j))*360/(2*pi);
%     C_lift=interp1(airfoil_data(:,1),airfoil_data(:,2),AoA_deg(j));
%     C_drag=interp1(airfoil_data(:,1),airfoil_data(:,3),AoA_deg(j));
    C_axial(j)=C_lift_opt*cos(phi(j))+C_drag_opt*sin(phi(j));
    C_radial(j)=C_lift_opt*sin(phi(j))-C_drag_opt*cos(phi(j));
   
   while error==1
     
      
           
       %Glauerts correction
       if a(j) < a_critical
           
        a_new=1/((4*F(j)*sin(phi(j))^2)/(sigma(j)*C_axial(j))+1);
       
       else 
           
            K(j)=(4*F(j)*sin(phi(j))^2)/(sigma(j)*C_axial(j));
            a_new=0.5*(2+K(j)*(1-2*a_critical)-sqrt((K(j)*...
                (1-2*a_critical)+2)^2+4*(K(j)*a_critical^2-1)));
           
        end
        
       
        adot_new=1/(4*F(j)*sin(phi(j))*cos(phi(j))/(sigma(j)*C_radial(j))-1);
  
        if abs(a_new-a(j)) > eps || abs(adot_new-adot(j)) > eps
           
            a(j)=a_new;
            adot(j)=adot_new;            
            phi(j)=(atan((V*(1-a(j))/((1+adot(j))*r(j)*omega)))) ;  
%             AoA_deg(j)=(phi(j)-theta(j))*360/(2*pi);
            theta(j)=phi(j)-AoA_opt_rad;
%             C_lift=interp1(airfoil_data(:,1),airfoil_data(:,2),AoA_deg(j));
%             C_drag=interp1(airfoil_data(:,1),airfoil_data(:,3),AoA_deg(j));   
            F(j)=(2/pi)*acos(exp(-(Z/2)*((rend-r(j))/(r(j)*sin(phi(j))))));
            C_axial(j)=C_lift_opt*cos(phi(j))+C_drag_opt*sin(phi(j));
            C_radial(j)=C_lift_opt*sin(phi(j))-C_drag_opt*cos(phi(j));
            
            
        else
           
            a(j)=a_new;
            adot(j)=adot_new;
            error=0;
            
        end
         
   end %end while loop for an element 
   
    error=1;

    thrust_list(j)=F(j)*C_axial(j)*0.5*dens*V^2*(1-a(j))^2/...
        (sin(phi(j))^2)*Lc(j)*dr*Z;  
    phi(j)=(atan((V*(1-a(j))/((1+adot(j))*r(j)*omega))));   
    torqueforce_element(j) = F(j)*C_radial(j)*(1/2)*dens*...
        ((V*(1-a(j)))/(sin(phi(j))))*((omega*r(j)*(1+adot(j)))/...
        (cos(phi(j))))*Lc(j)*dr*Z;
    torque_list(j)=torqueforce_element(j).*r(j);
    power_list_AoA(j)=torque_list(j)*lambda_r(j);
 
end %end for loop elements 
torqueforce_tot=sum(torqueforce_element);
torque_tot=sum(torque_list);
power_tot=torque_tot*omega;
power_coeff=power_tot/(0.5*dens*V^3*pi*d^2/4);
thrust_tot=sum(thrust_list);
theta=theta*180/pi;

%plots should be made smoother, using subplots, maybe uicontrol and string 
%texts. 
 %plots for selected velocity V and TSR
        if V == (10+bias) 
            figure(1);
            plot(r(1:end)/rend,a(1:end),r(1:end)/rend,adot(1:end))
            legend('a values','adot values', 'Location','northwest')
            xlabel('r/R')
            figure(2);
            plot(r(1:end)/rend,torqueforce_element(1:end),r(1:end)...
                /rend,thrust_list(1:end))
            legend('torque[force]','thrust', 'Location','northwest')
            xlabel('r/R')
            figure(3);
            plot(r(1:end)/rend,Lc(1:end))
            legend('chordlengths')
            xlabel('r/R')
        end
        %Writes to Command Window for selected velocity and TSR
        if  V == (10+bias) 
            formatSpec='The total power produced is %4.1f W\n';
            fprintf(formatSpec,power_tot)
            formatSpec='The power coefficient is %4.3f\n';
            fprintf(formatSpec,power_coeff)
            formatSpec='The totalt thrust is %4.2f N\n';
            fprintf(formatSpec,thrust_tot)
            
        end
        
        fprintf( fid, '%2.1f\t%1.4f\t%2.3f\t%7.2f\n',V...
            ,power_tot,power_coeff,thrust_tot );
 fprintf( fid2, '%2.4f\t%2.4f\n',theta,Lc );
end
fclose ( fid ); 
fclose ( fid2 ); 
