%Master Thesis
%Rasmus Borenius
%Combinde Wind an Wave Power
%NTNU
 clear 
 clear all 

N=100;  %blade elements (remember to change number also in adisk.m!!!)
d=123; 
V1=10; %m/s
TSR=8;  %tip speed ratio 
Z=3;   %number of blades 
omega=TSR*V1/(d/2);
dens=1.204;
%first blade element starts at : hub radius + circular disk = 6 cm 
r0=6;
rend=63;
R=rend-r0;
dr=R/N;
%taking midpoint of elements
r=r0+dr/2:dr:rend;
r=r';


lambda_r=omega/V1*r;
[a, adot, Bep, phi ]=adisk(lambda_r,N); %calculating local lamdas from table 107

phi=phi';
a=a';
adot=adot';
Bep=Bep';

airfoil_data=loaddata;

lift_to_drag_list=airfoil_data(:,2)./airfoil_data(:,3);

[lift_to_drag_max,location_list]=max(lift_to_drag_list);

A_opt_deg=airfoil_data(location_list,1);
A_opt_rad=A_opt_deg*2*pi/360;

C_lift_opt=airfoil_data(location_list,2);
C_drag_opt=airfoil_data(location_list,3);


Lc=Bep*2*pi*V1/(Z*C_lift_opt*omega);

 sigma=Z*Lc./(2*pi*r);
 a_critical=0.2;
 eps=10^-6; %toleranse 
 error=1;
  counter=0 ;
theta=phi-A_opt_rad;  %locked 
  a=0.25*ones(N,1);   %must be chosen in the interval [0.25, 0.33]
  adot=0.01*zeros(N,1);
% adot=0.333*(N,1);
% a=0.001*ones(N,1);

for j=1:N    
    counter=counter+1;
    phi(j)=(atan((V1*(1-a(j))/((1+adot(j))*r(j)*omega))));    
    F(j)=(2/pi)*acos(exp(-(Z/2)*((rend-r(j))/(r(j)*sin(phi(j))))));
    AoA_deg(j)=(phi(j)-theta(j))*360/(2*pi);
    C_lift=interp1(airfoil_data(:,1),airfoil_data(:,2),AoA_deg(j));
    C_drag=interp1(airfoil_data(:,1),airfoil_data(:,3),AoA_deg(j));
    C_axial(j)=C_lift*cos(phi(j))+C_drag*sin(phi(j));
    C_radial(j)=C_lift*sin(phi(j))-C_drag*cos(phi(j));
   
   while error==1
     
      
           
       %Glauerts correction
       if a(j) < a_critical
           
        a_new=1/((4*F(j)*sin(phi(j))^2)/(sigma(j)*C_axial(j)));
       
       else 
           
            K(j)=(4*F(j)*sin(phi(j))^2)/(sigma(j)*C_axial(j));
            a_new=0.5*(2+K(j)*(1-2*a_critical)-sqrt((K(j)*...
                (1-2*a_critical)+2)^2+4*(K(j)*a_critical^2-1)));
           
        end
        
       
        adot_new=1/(4*F(j)*sin(phi(j))*cos(phi(j))/(sigma(j)*C_radial(j))-1);
  
        if abs(a_new-a(j)) > eps || abs(adot_new-adot(j)) > eps
           
            a(j)=a_new;
            adot(j)=adot_new;            
            phi(j)=(atan((V1*(1-a(j))/((1+adot(j))*r(j)*omega)))) ;  
            AoA_deg(j)=(phi(j)-theta(j))*360/(2*pi);
            C_lift=interp1(airfoil_data(:,1),airfoil_data(:,2),AoA_deg(j));
            C_drag=interp1(airfoil_data(:,1),airfoil_data(:,3),AoA_deg(j));   
            F(j)=(2/pi)*acos(exp(-(Z/2)*((rend-r(j))/(r(j)*sin(phi(j))))));
            C_axial(j)=C_lift*cos(phi(j))+C_drag*sin(phi(j));
            C_radial(j)=C_lift*sin(phi(j))-C_drag*cos(phi(j));
            
            
        else
           
            a(j)=a_new;
            adot(j)=adot_new;
            error=0;
            
        end
         
   end %end while loop for an element 
   
    error=1;

    thrust_list(j)=F(j)*C_axial(j)*0.5*dens*V1^2*(1-a(j))^2/...
        (sin(phi(j))^2)*Lc(j)*dr*Z;  
    phi(j)=(atan((V1*(1-a(j))/((1+adot(j))*r(j)*omega))));   
    torqueforce_element(j) = F(j)*C_radial(j)*(1/2)*dens*((V1*(1-a(j)))/(sin(phi(j))))*((omega*r(j)*(1+adot(j)))/(cos(phi(j))))*Lc(j)*dr*Z;
    torque_list(j)=torqueforce_element(j).*r(j);
    torque_list=torque_list';
    power_list(j)=torque_list(j)*lambda_r(j);
end %end for loop elements 
torqueforce_tot=sum(torqueforce_element);
torque_tot=sum(torque_list);
power_tot=torque_tot*omega;
power_coeff=power_tot/(0.5*dens*V1^3*pi*d^2/4);
thrust_tot=sum(thrust_list);


%plots should be made smoother, using subplots, maybe uicontrol and string 
%texts. 
figure(1);
plot(r(1:end)/rend,a(1:end),r(1:end)/rend,adot(1:end))
legend('a values','adot values')
xlabel('r/R')
figure(2);
plot(r(1:end)/rend,torqueforce_element(1:end),r(1:end)/rend,thrust_list(1:end))
legend('torque[force]','thrust')
xlabel('r/R')
figure(3);
plot(r(1:end)/rend,Lc(1:end))
legend('chordlengths')
xlabel('r/R')

formatSpec='The total power produced is %4.1f W\n';
fprintf(formatSpec,power_tot)
formatSpec='The power coefficient is %4.3f\n';
fprintf(formatSpec,power_coeff)
formatSpec='The totalt thrust is %4.2f N\n';
fprintf(formatSpec,thrust_tot)

theta=phi*180/pi-AoA_deg';
