%Master Thesis
%Rasmus Borenius
%Combinde Wind an Wave Power
%NTNU

clear 
clear all 

N=100;  %blade elements (remember to change number also in adisk.m!!!)
d=126;
V1=12; %m/s
TSR=8;  %tip speed ratio 
Z=3;   %number of blades 
omega=TSR*V1/(d/2);
dens=1.204;
%first blade element starts at : hub radius + circular disk = 6 cm 
r0=6;
rend=63;
R=rend-r0;
dr=R/N;
%taking midpoint of elements
r=r0+dr/2:dr:rend;
r=r';


lambda_r=omega/V1*r;
[a, adot, Bep, phi ]=adisk(lambda_r,N); %calculating local lamdas from table 107

phi=phi';
a=a';
adot=adot';
Bep=Bep';

airfoil_data=loaddata;

lift_to_drag_list=airfoil_data(:,2)./airfoil_data(:,3);

[lift_to_drag_max,location_list]=max(lift_to_drag_list);

AoA_opt_deg=airfoil_data(location_list,1);
AoA_opt_rad=AoA_opt_deg*2*pi/360;

C_lift_opt=airfoil_data(location_list,2);
C_drag_opt=airfoil_data(location_list,3);

%
percent_list=(0.8:0.1:1.2);


Lc=Bep*2*pi*V1/(Z*C_lift_opt*omega);
Lc_matrix=Lc*percent_list ;

 a_critical=0.2;
 eps=10^-6; %toleranse 
 error=1;
  counter=0 ;
theta=phi-AoA_opt_rad;  %locked 
  a=0.33*ones(N,length(percent_list));   %must be chosen in the interval [0.25, 0.33]
  adot=0.01*zeros(N,length(percent_list));
% adot=0.333*(N,1);
% a=0.001*ones(N,1);

for j=1:N    %loop over blade elements 
    
     
     
     for k=1:length(percent_list) %loop over different guess of Lc 
       
         error=1;
        sigma(j,k)=Z*Lc_matrix(j,k)/(2*pi*r(j));
        phi(j,k)=(atan((V1*(1-a(j))/((1+adot(j))*r(j)*omega)))); 
        theta(j,k)=phi(j,k)-AoA_opt_rad;
        F(j,k)=(2/pi)*acos(exp(-(Z/2)*((rend-r(j))/(r(j)*sin(phi(j,k))))));
        C_axial(j,k)=C_lift_opt*cos(phi(j,k))+C_drag_opt*sin(phi(j,k));
        C_radial(j,k)=C_lift_opt*sin(phi(j,k))-C_drag_opt*cos(phi(j,k));
   
        while error==1
       
            if a(j,k) < a_critical
           
                a_new=1/((4*F(j,k)*sin(phi(j,k))^2)/(sigma(j,k)*C_axial(j,k)));
       
            else 
           
            K(j,k)=(4*F(j,k)*sin(phi(j,k))^2)/(sigma(j,k)*C_axial(j,k));
            a_new=0.5*(2+K(j,k)*(1-2*a_critical)-sqrt((K(j,k)*...
                (1-2*a_critical)+2)^2+4*(K(j,k)*a_critical^2-1)));
           
            end
        
       
            adot_new=1/(4*F(j,k)*sin(phi(j,k))*cos(phi(j,k))/(sigma(j,k)*C_radial(j,k))-1);
  
            if abs(a_new-a(j,k)) > eps || abs(adot_new-adot(j,k)) > eps
           
            a(j,k)=a_new;
            adot(j,k)=adot_new;            
            phi(j,k)=(atan((V1*(1-a(j,k))/((1+adot(j,k))*r(j)*omega)))) ;  
%             AoA_deg(j)=(phi(j)-theta(j))*360/(2*pi);
            theta(j,k)=phi(j,k)-AoA_opt_rad;
%             C_lift=interp1(airfoil_data(:,1),airfoil_data(:,2),AoA_deg(j));
%             C_drag=interp1(airfoil_data(:,1),airfoil_data(:,3),AoA_deg(j));   
            F(j,k)=(2/pi)*acos(exp(-(Z/2)*((rend-r(j))/(r(j)*sin(phi(j,k))))));
            C_axial(j,k)=C_lift_opt*cos(phi(j,k))+C_drag_opt*sin(phi(j,k));
            C_radial(j,k)=C_lift_opt*sin(phi(j,k))-C_drag_opt*cos(phi(j,k));
            
            
        else
           
            a(j,k)=a_new;
            adot(j,k)=adot_new;
            error=0;
            
            end  
         
        end %end convergence loop 
        
        thrust_list_percent(j,k)=F(j,k)*C_axial(j,k)*0.5*dens*V1^2*...
            (1-a(j,k))^2/(sin(phi(j,k))^2)*Lc_matrix(j,k)*dr*Z;  
        torqueforce_element_percent(j,k) = F(j,k)*C_radial(j,k)*(1/2)*...
            dens*((V1*(1-a(j,k)))/(sin(phi(j,k))))*((omega*r(j)*...
            (1+adot(j,k)))/(cos(phi(j,k))))*Lc_matrix(j,k)*dr*Z;
     end %end Lc guess loop 
    [torqueforce_max,max_location]=max(torqueforce_element_percent(j,:));    
    torque_list(j)=torqueforce_element_percent(j,max_location)*r(j);
    thrust_list(j)=thrust_list_percent(j,max_location);
    a_list(j)=a(j,max_location);
    adot_list(j)=adot(j,max_location);
    Lc(j)=Lc_matrix(j,max_location);
    theta_list(j)=theta(j,max_location);
end %end blade element loop 
torque_tot=sum(torque_list);
power_tot=torque_tot*omega;
power_coeff=power_tot/(0.5*dens*V1^3*pi*d^2/4);
thrust_tot=sum(thrust_list);

% 

figure(1);
plot(r/rend,a_list,r/rend,adot_list)
legend('a values','adot values')
xlabel('r/R')
figure(2);
plot(r/rend,torque_list',r/rend,thrust_list')
legend('torque[force]','thrust')
xlabel('r/R')
figure(3);
plot(r/rend,Lc)
legend('chordlengths')
xlabel('r/R')

formatSpec='The total power produced is %4.1f W\n';
fprintf(formatSpec,power_tot)
formatSpec='The power coefficient is %4.3f\n';
fprintf(formatSpec,power_coeff)
formatSpec='The totalt thrust is %4.2f N\n';
fprintf(formatSpec,thrust_tot)
